@@ -3,8 +3,8 @@ This is part of the MSS Python's module.
 Source: https://github.com/BoboTiG/python-mss
 """
 import os.path
+import sys
 from argparse import ArgumentParser
-from typing import List, Optional
 
 from . import __version__
 from .exception import ScreenShotError
@@ -12,10 +12,10 @@ from .factory import mss
 from .tools import to_png
 
 
-def main(args: Optional[List[str]] = None) -> int:
+def main(*args: str) -> int:
     """Main logic."""
 
-    cli_args = ArgumentParser()
+    cli_args = ArgumentParser(prog="mss")
     cli_args.add_argument(
         "-c",
         "--coordinates",
@@ -31,12 +31,9 @@ def main(args: Optional[List[str]] = None) -> int:
         choices=list(range(10)),
         help="the PNG compression level",
     )
-    cli_args.add_argument(
-        "-m", "--monitor", default=0, type=int, help="the monitor to screen shot"
-    )
-    cli_args.add_argument(
-        "-o", "--output", default="monitor-{mon}.png", help="the output file name"
-    )
+    cli_args.add_argument("-m", "--monitor", default=0, type=int, help="the monitor to screen shot")
+    cli_args.add_argument("-o", "--output", default="monitor-{mon}.png", help="the output file name")
+    cli_args.add_argument("--with-cursor", default=False, action="store_true", help="include the cursor")
     cli_args.add_argument(
         "-q",
         "--quiet",
@@ -46,7 +43,7 @@ def main(args: Optional[List[str]] = None) -> int:
     )
     cli_args.add_argument("-v", "--version", action="version", version=__version__)
 
-    options = cli_args.parse_args(args)
+    options = cli_args.parse_args(args or None)
     kwargs = {"mon": options.monitor, "output": options.output}
     if options.coordinates:
         try:
@@ -65,7 +62,7 @@ def main(args: Optional[List[str]] = None) -> int:
             kwargs["output"] = "sct-{top}x{left}_{width}x{height}.png"
 
     try:
-        with mss() as sct:
+        with mss(with_cursor=options.with_cursor) as sct:
             if options.coordinates:
                 output = kwargs["output"].format(**kwargs["mon"])
                 sct_img = sct.grab(kwargs["mon"])
@@ -78,10 +75,10 @@ def main(args: Optional[List[str]] = None) -> int:
                         print(os.path.realpath(file_name))
             return 0
     except ScreenShotError:
-        return 1
+        if options.quiet:
+            return 1
+        raise
 
 
-if __name__ == "__main__":
-    import sys
-
-    sys.exit(main(sys.argv[1:]))
+if __name__ == "__main__":  # pragma: nocover
+    sys.exit(main())
